@@ -175,6 +175,20 @@ class bfit(object):
                             "Positive Helicity", 
                             "Negative Helicity", 
                             ], 
+                      '1d':["Combined Helicity", 
+                            "Split Helicity", 
+                            "Raw Scans", 
+                            "Histograms", 
+                            "Positive Helicity", 
+                            "Negative Helicity", 
+                            ], 
+                      '1c':["Combined Helicity", 
+                            "Split Helicity", 
+                            "Raw Scans", 
+                            "Histograms", 
+                            "Positive Helicity", 
+                            "Negative Helicity", 
+                            ], 
                       '1w':["Combined Helicity", 
                             "Split Helicity", 
                             "Raw Scans", 
@@ -254,6 +268,8 @@ class bfit(object):
                  '1f':'Frequency (%s)', 
                  '1w':'x Parameter (%s)', 
                  '1e':'Field (G)', 
+                 '1d':'Laser Power', 
+                 '1c':'Camp Variable', 
                  '1n':'Voltage (%s)'}
                  
     ylabel_dict={'ad':r'$N_\alpha~/~N_\beta$', # otherwise, label as Asymmetry
@@ -273,6 +289,9 @@ class bfit(object):
            '2e':"time", 
            '1f':'freq', 
            '1w':'xpar', 
+           '1d':'las', 
+           '1e':'mA', 
+           '1c':'camp', 
            '1n':'mV'}
     
     # minimizers
@@ -323,7 +342,8 @@ class bfit(object):
         self.units = {  '1f':[1e-6, 'MHz'], 
                         '2e':[1e-6, 'MHz'], 
                         '1w':[1, 'Hz'], 
-                        '1n':[1e-3, 'V'],
+                        '1n':[0.001, 'V'],
+                        '1e':[0.001, 'A'],
                         '20':[1, 's'],
                         '2h':[1, 's'],
                         }
@@ -888,13 +908,35 @@ class bfit(object):
             x = a[self.x_tag[data.mode]]
             xlabel = self.xlabel_dict[data.mode]
             
-            if data.mode in self.units.keys():
+            # get bfit-defined units
+            if data.mode in self.units.keys() and self.units[data.mode][1].lower() \
+                                                  not in ('default', 'disable'):                                                     
                 unit = self.units[data.mode]
                 xlabel = xlabel % unit[1]
             
+            # get units for custom scans
+            elif 'scan_var_histo_factor' in data.ppg.keys():
+                unit = [data.ppg.scan_var_histo_factor.mean,
+                        data.ppg.scan_var_histo_factor.units]     
+                   
+                # check custom name
+                if 'customv_enable' in data.ppg.keys() and bool(data.ppg.customv_enable.mean):
+                    xlabel = '%s (%s)' % (data.ppg.customv_name_write.units, unit[1])
+                    
+                # 1c runs custom name
+                elif 'scan_device' in data.ppg.keys():
+                    xlabel = '%s (%s)' % (data.ppg.scan_device.units, unit[1])
+                
+                # no name, use default
+                else:
+                    xlabel = xlabel % unit[1]
+                        
+            else:
+                unit = [1, 'default']
+                xlabel = xlabel % unit[1]
+                        
             # unit conversions
             if data.mode in ('1n', '1w'): 
-                unit = self.units[data.mode]
                 x *= unit[0]
                 
             elif data.mode == '1f': 
@@ -904,7 +946,6 @@ class bfit(object):
                     x = 1e6*(x-self.ppm_reference)/self.ppm_reference
                     xlabel = 'Frequency Shift (PPM)'
                 else: 
-                    unit = self.units[data.mode]
                     x *= unit[0]
             
             # plot split helicities
@@ -929,7 +970,7 @@ class bfit(object):
                 self.plt.axhline(figstyle, 'line', avg, color='k', linestyle='--')
                 
             # plot positive helicity
-            elif asym_type == 'p':
+            elif asym_type == 'sp':
                 
                 # remove zero asym
                 ap = a.p[0]
@@ -1278,9 +1319,6 @@ class bfit(object):
         if figstyle != 'periodic':
             raise_window()   
             
-        
-        
-        
         self.logger.debug('Drawing success.')
     
     # ======================================================================= #
